@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998-2003, 2006-2008, 2010, 2012 Peter Miller
+// Copyright (C) 1998-2003, 2006-2008, 2010, 2012-2014 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -20,9 +20,13 @@
 #ifndef SRECORD_MEMORY_H
 #define SRECORD_MEMORY_H
 
+#include <string>
+
+#include <srecord/defcon.h>
 #include <srecord/input.h>
 #include <srecord/memory/chunk.h>
 #include <srecord/memory/walker.h>
+#include <srecord/string.h>
 
 namespace srecord {
 
@@ -104,14 +108,21 @@ public:
       * header, the first header will be remembered, if set_header()
       * was not called previously.
       *
-      * If the value at any address is set more than once, a fatal
-      * error will be issued, informing the user of the address
-      * and the contradictory values.  If the allow_overwriting()
-      * method has been called previously, this will be a non-fatal
-      * warning, instead.  If `barf' is false, no checking of any
-      * kind is performed.
+      * @param input
+      *     The source of the byte stream
+      * @param redundant_bytes
+      *     ignore: do nothing
+      *     warning: issue a warning and continue (default)
+      *     error: issuse a atal error message, and exit failure.
+      * @param contradictory_bytes
+      *     If the value at any address is set more than once,
+      *     Thid argument controls what happeens.
+      *     ignore: do nothing
+      *     warning: issue a warning and continue (default)
+      *     error: issuse a atal error message, and exit failure (default).
       */
-    void reader(const input::pointer &input, bool barf = false);
+    void reader(const input::pointer &input, defcon_t redundant_bytes,
+        defcon_t contradictory_bytes);
 
     /**
       * The equal method may be used to determine if two memory
@@ -141,25 +152,22 @@ public:
     bool find_next_data(unsigned long &address, void *data,
         size_t &nbytes) const;
 
-    /**
-      * The allow_overwriting controls the error message behaviour of
-      * the reader() method.  Once called, redundant and contradictory
-      * settings generate warnings, rather than fatal errors.
-      */
-    static void allow_overwriting(void);
-
     /**
       * The get_header method is used to determine the value of the
       * header record set by either the reader() or set_header()
-      * methods.  If neither has set a header, NULL is returned.
+      * methods.  If neither has set a header, a NULL is returned.
       */
     record *get_header(void) const;
 
     /**
       * The set_header method may be used to set the header command.
-      * The `value' is a NUL terminated C string.
+      *
+      * @param value
+      *     The `value' string, to set the header.  The user may use URL
+      *     encoding for of the more interesting non-printable byte values
+      *     (eg. "%3F").
       */
-    void set_header(const char *value);
+    void set_header(const std::string &value);
 
     /**
       * The get_execution_start_address method is used to determine the
@@ -187,6 +195,18 @@ public:
     bool has_holes(void) const;
 
     /**
+      * The get_lower_bound method is used to obtain the lower bound
+      * (lowest address) of the memory image.
+      */
+    unsigned long get_lower_bound() const;
+
+    /**
+      * The get_upper_bound method is used to obtain the upper bound
+      * (maximum address plus one) of the memory image.
+      */
+    unsigned long get_upper_bound() const;
+
+   /**
       * The is_well_aligned method is used to test whether or not
       * all of the data in the memory buffer is well aligned, on the
       * given byte boundary.
@@ -212,13 +232,6 @@ public:
     }
 
 private:
-    /**
-      * The overwrite static variable is used to remember whether
-      * or not we generate warnings when redundant or contradictory
-      * settings are deteccted by the reader() method.
-      */
-    static bool overwrite;
-
     /**
       * The nchunks instance variable is used to member how large
       * our pool of memory chunks is.  It is always <= nchunks_max;
@@ -295,12 +308,6 @@ private:
       * this object.  Only to be used the the assignment operator.
       */
     void copy(const memory &src);
-
-    /**
-      * The get_upper_bound method is used to obtain the upper bound
-      * (maximum address plus one) of the memory image.
-      */
-    unsigned long get_upper_bound(void) const;
 };
 
 };
